This function predicts if the edge diractions are wrong based on graphical position of the KEGG nodes
Source:R/kegg.functions.R
isReverseDirection.RdThis function predicts if the edge diractions are wrong based on graphical position of the KEGG nodes