Remove nodes which do not have any interactions with other nodes
Source:R/kegg.functions.R
remove.disconnected.nodes.RdRemove nodes which do not have any interactions with other nodes
R/kegg.functions.R
remove.disconnected.nodes.RdRemove nodes which do not have any interactions with other nodes