Calculates pathway activity with PSF algorithm for provided kegg collection based on expression fold change data.
Source:R/pathnet.functions.R
psf.from.env.entrez.fc.RdCalculates pathway activity with PSF algorithm for provided kegg collection based on expression fold change data.
Usage
psf.from.env.entrez.fc(
entrez.fc,
kegg.collection,
split = TRUE,
calculate.significance = T,
bst.steps = 200,
sum = FALSE,
map_exp_data = TRUE,
return_only_signals = FALSE,
tmm_mode = FALSE,
tmm_updated_mode = FALSE
)Arguments
- entrez.fc
expression fold change matrix with gene etrez id rownames.
- kegg.collection
the list of kegg pathways generated by generate.kegg.collection.from.kgml or generate.kegg.collection function.
- split
logical, if true then the incoming signal will be proportionally splitted among the edges.
- calculate.significance
logical, if true then function will also calculate significance for the PSF values by shuffling all the network nodes and checking if the resulted PSF values were calculated by chance.
- bst.steps
integer, the number of the interations for shuffling and recalculating PSF values for the significance analysis.
- sum
logical, default value is FALSE. When set to true pathway activity will be caculated via addition, when set to false then activity willbe calculated via multiplication.
- map_exp_data
logical, default value is TRUE. When set to false the expression data will not be mapped into pathway nodes and pathway node expression values will be used instead.
- return_only_signals
logical, default value is FALSE. When set to true only PSF values of the pathway nodes will be retruned in the results. Set to TRUE when analyzing large datasets to reduce size of the output file.
- tmm_mode
when set to true specific PSF configuration will be used for the pathway activity calculation described in https://www.frontiersin.org/articles/10.3389/fgene.2021.662464/full
- tmm_updated_mode
when set to true specific PSF configuration will be used for the pathway activity calculation described in https://www.frontiersin.org/articles/10.3389/fgene.2021.662464/full